/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jbpm.env.session;

/** indicates when the processDefinition logs that are generated during processDefinition 
 * execution should be parsed and inserted into the business intelligence 
 * store.
 * 
 * @author Tom Baeyens
 */
public enum LogMode {

  /**
   * the processDefinition logs will be parsed and inserted into the business intelligence 
   * database directly in each transaction.  The textual log representation will 
   * never be stored.  This log mode insures that the business intelligence 
   * store will always be in sync with the current processDefinition executions.
   */
  INSIDE_EACH_TRANSACTION,
  
  /** the processDefinition logs will be parsed after each runtime execution transaction 
   * asynchronously.  This way the runtime processDefinition execution transaction will 
   * end faster but you yave a very short time window (between committing of 
   * the runtime transaction and processing of the logs asynchronously) in 
   * which the business intelligence store is out of sync with the runtime 
   * state of the processDefinition executions.
   */
  ASYNC_AFTER_EACH_TRANSACTION,
  
  /** the processDefinition logs will be parsed into the business intelligence store 
   * in the transaction where the processDefinition execution finishes.  
   */
  INSIDE_END_TRANSACTION,
  
  /** the processDefinition logs will be parsed into the business intelligence store 
   * in a separate transaction after the transaction in which the processDefinition 
   * execution finished.  
   */
  ASYNC_AFTER_END_TRANSACTION
}
