/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jbpm.env.xml;

import org.jbpm.env.impl.DefaultEnvironment;
import org.jbpm.env.impl.DefaultEnvironmentFactory;
import org.jbpm.wire.WireContext;
import org.jbpm.wire.WireDefinition;
import org.jbpm.wire.xml.WireParser;
import org.jbpm.xml.Parse;
import org.jbpm.xml.Parser;
import org.jbpm.xml.XmlUtil;
import org.w3c.dom.Document;
import org.w3c.dom.Element;

/**
 * @author Tom Baeyens
 */
public class EnvironmentParser extends Parser {

  private static final long serialVersionUID = 1L;

  WireParser applicationWireXmlParser = new EnvironmentApplicationXmlParser();
  WireParser blockWireXmlParser = new EnvironmentBlockXmlParser();

  public Object parseDocument(Document document, Parse parse) {
    Element documentElement = document.getDocumentElement();
    
    // if the default environment factory was already set in the parse
    // (see also {@link DefaultEnvironmentFactory#DefaultEnvironmentFactory(String, ClassLoader)})
    DefaultEnvironmentFactory defaultEnvironmentFactory = parse.findObject(DefaultEnvironmentFactory.class);
    if (defaultEnvironmentFactory==null) {
      defaultEnvironmentFactory = new DefaultEnvironmentFactory();
      parse.pushObject(defaultEnvironmentFactory);
    }
    
    WireDefinition applicationWireDefinition = getApplicationWireDefinition(documentElement, parse);
    WireDefinition blockWireDefinition = getBlockWireDefinition(documentElement, parse);

    // create the application wire context from the definition
    WireContext applicationWireContext = new WireContext(applicationWireDefinition, DefaultEnvironment.CONTEXTNAME_APPLICATION, defaultEnvironmentFactory);
    // propagate the parser classloader to the application context
    applicationWireContext.setClassLoader(classLoader);

    // configure the default environment factory
    defaultEnvironmentFactory.setApplicationWireContext(applicationWireContext);
    defaultEnvironmentFactory.setBlockWireDefinition(blockWireDefinition);
    
    parse.setDocumentObject(defaultEnvironmentFactory);

    return defaultEnvironmentFactory;
  }

  WireDefinition getApplicationWireDefinition(Element documentElement, Parse parse) {
    Element applicationElement = XmlUtil.element(documentElement, DefaultEnvironment.CONTEXTNAME_APPLICATION);
    if (applicationElement != null) {
      return (WireDefinition) applicationWireXmlParser.parseDocumentElement(applicationElement, parse);
    }
    return null;
  }

  WireDefinition getBlockWireDefinition(Element documentElement, Parse parse) {
    Element blockElement = XmlUtil.element(documentElement, DefaultEnvironment.CONTEXTNAME_BLOCK);
    if (blockElement != null) {
      return (WireDefinition) blockWireXmlParser.parseDocumentElement(blockElement, parse);
    }
    return null;
  }

  public WireParser getApplicationWireXmlParser() {
    return applicationWireXmlParser;
  }
  public void setApplicationWireXmlParser(WireParser applicationWireXmlParser) {
    this.applicationWireXmlParser = applicationWireXmlParser;
  }
  public WireParser getBlockWireXmlParser() {
    return blockWireXmlParser;
  }
  public void setBlockWireXmlParser(WireParser blockWireXmlParser) {
    this.blockWireXmlParser = blockWireXmlParser;
  }
}
