package org.jbpm.jobexecutor;

import java.util.List;

import org.jbpm.env.session.Job;
import org.jbpm.env.session.Timer;
import org.jbpm.pvm.Execution;

/**
 * @author Tom Baeyens, Pascal Verdage
 */
public interface JobSession {

	/** save a job */
	public void save(Job<?> job);

	/** delete a job */
	public void delete(Job<?> job);

	/** @return the first job to finish among eligible and non-locked jobs or null if none */
	public Job<?> getFirstAcquirableJob();

	/** @return the list of jobs of the process instance that mustn't be concurrent */
	public List<Job<?>> findExclusiveJobs(Execution processInstance);

	/** @return the first job to finish among non-owned jobs or null if none */
	public Job<?> getFirstDueJob();

	/** @return the job with the given id or null if none */
	public Job<?> get(long jobId);

	/** @return the next timer that will fire or null if none */
	public Timer findNextTimer();

	/** @return all the timers */
	public List<Timer> findAllTimers();
	
	/** @return all the timers scheduled on a given execution */
	public List<Timer> findTimers(Execution execution);
}
