/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jbpm.jobexecutor;

import java.util.List;

import org.hibernate.Query;
import org.jbpm.env.session.Job;
import org.jbpm.env.session.Timer;
import org.jbpm.hibernate.HibernatePvmDbSession;
import org.jbpm.pvm.Execution;
import org.jbpm.util.Clock;

/**
 * @author Tom Baeyens
 */
public class StandardJobSession implements JobSession {
  
  HibernatePvmDbSession hibernateSession;

  public Job<?> getFirstAcquirableJob() {
    Query query = hibernateSession.getSession().getNamedQuery("getFirstAcquirableJob");
    query.setTimestamp("now", Clock.getCurrentTime());
    query.setMaxResults(1);
    return (Job<?>) query.uniqueResult();
  }

  public List<Job<?>> findExclusiveJobs(Execution processInstance) {
    Query query = hibernateSession.getSession().getNamedQuery("findExclusiveJobs");
    query.setTimestamp("now", Clock.getCurrentTime());
    query.setEntity("processInstance", processInstance);
    return query.list();
  }

  public Job<?> getFirstDueJob() {
    Query query = hibernateSession.getSession().getNamedQuery("getFirstDueJob");
    query.setMaxResults(1);
    return (Job<?>) query.uniqueResult();
  }

  public void delete(Job<?> job) {
	  hibernateSession.delete(job);
  }

  public void save(Job<?> job) {
	  hibernateSession.save(job);
  }

  public Job<?> get(long jobId) {
	  return hibernateSession.get(Job.class, jobId);
  }

  public List<Timer> findAllTimers() {
	  return hibernateSession.findAllTimers();
  }

  public Timer findNextTimer() {
	  return hibernateSession.findNextTimer();
  }

  public List<Timer> findTimers(Execution execution) {
	return hibernateSession.findTimers(execution);
  }

}
