/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jbpm.pvm;


/**
 * can handle exceptions that occur in user code like {@link Activity}s 
 * and {@link ExternalActivity}s.
 * 
 * To better understand what exception handlers can do and what they 
 * can't do, we have to look at persistence.  When an exception comes 
 * out of an {@link Execution}, it can be in an inconsistent state.  
 * Therefore, when an exception occurs in a persistent transaction, 
 * clients cannot persist that execution.  So the only option is to 
 * rollback the transaction. As a consequence of a rollback, any 
 * resource update done as part of exception handling is compensated 
 * as well.
 * 
 * TODO separate between ExceptionHandlers for actions (in that case 
 * they CAN control flow of execution) and exception handlers for nodes
 * (in that case exception handlers can only rethrow, which means 
 * rollback or they handle the exception and then continue execution 
 * as planned.
 * 
 * TODO add option to run exception handlers in a separate transaction
 * so that the processDefinition updates are rolled back, but that rollback 
 * is immediately followed by a new transaction that will get the 
 * execution and the exception in a new transaction.  
 * 
 * @author Tom Baeyens
 */
public interface ExceptionHandler {

  /** the meaningless database primary key */
  long getDbid();

  String getExceptionClassName();
}