/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jbpm.pvm;

import java.util.Map;

/** a super class for process elements that have events.
 * 
 * @author Tom Baeyens
 */
public interface ObservableElement extends ProcessElement {
  
  /** the short display name given to this element. */
  String getName();

  /** the long description. */
  String getDescription();

  /** by default, this implementation returns null, but this is overwritten 
   * in {@link Node} and {@link Transition} to represent the parent in the 
   * hierarchical structure of the process.  This hierarchical structure is 
   * used for <a href="package-summary.html#events">event propagation</a>.
   */
  ObservableElement getParent();

  /** listeners, partitioned by event name. 
   * Beware: the actual member is returned.  No copy is made. */
  Map<String, Event> getEvents();
  
  /** listeners for a specific event. */
  Event getEvent(String eventName);
  
  /** check for presence of a given eventName. */  
  boolean hasEvent(String eventName);
}
