/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jbpm.pvm;

import java.util.Map;
import java.util.Set;

/** a scope of variables {@link Execution#getVariableScopeIterator() associated to an execution}.
 * 
 * <p>Users should use the convenience methods on execution
 * <ul>
 *   <li>{@link Execution#getVariable(String)}</li>
 *   <li>{@link Execution#getVariableKeys()}</li>
 *   <li>{@link Execution#getVariables()}</li>
 *   <li>{@link Execution#setVariable(String, Object)}</li>
 *   <li>{@link Execution#setVariables(Map)}</li>
 * </ul>
 * </p>
 * 
 * <p>This interface is created so that process languages can embed their 
 * variable scopes in other objects.  E.g. by default, the ExecutionImpl class 
 * manages a list of VariableScope's.  But the execution subclass for individual 
 * process languages can overwrite the usage of that member and get the 
 * variable scopes from some other member.
 * </p> 
 * 
 * @author Tom Baeyens
 */
public interface VariableScope {

  /** retrieve an object from this scope */
  Object get(String key);
  
  /** set an object in this scope */
  void set(String key, Object value);
  
  /** check for presence of a key in this scope */
  boolean has(String key);
  
  /** remove the entry for the given key from this scope */
  boolean remove(String key);

  /** checks if this scope is empty */ 
  boolean isEmpty();
  
  /** all the keys that are present in this scope */
  Set<String> keys();
  
  /** retrieves all entries in this variable scope */
  Map<String, Object> getAll();
}
