/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jbpm.pvm.impl;

import java.util.List;
import java.util.NoSuchElementException;

/**
 * @author Tom Baeyens
 */
public abstract class ExecutionScopeIterator {

  protected ExecutionImpl execution;
  protected List<Object> scopeList;
  protected int index = -1;
  protected Object next;
  protected boolean isConsumed;
  protected List<Object> lastConsumedScopeList;
  protected int lastConsumedIndex;

  public ExecutionScopeIterator(ExecutionImpl execution) {
    this.execution = execution;
  }

  protected abstract boolean isWanted(Object executionScope);
  protected abstract List getScopeListFromExecution();

  public boolean hasNext() {
    return findNext();
  }

  public Object next() {
    findNext();
    if (next!=null) {
      return consumeNext();
    } else {
      throw new NoSuchElementException();
    }
  }

  public void remove() {
    lastConsumedScopeList.remove(lastConsumedIndex);
  }

  private boolean findNext() {
    if ( (next!=null) && (!isConsumed) ) {
      return true;
    }
    next = null;
    isConsumed = false;
    while (execution!=null) {
      scopeList = findNextScopeList();
      if (scopeList!=null) {
        index = findNextExecutionScopeIndex();
        if (index==-1) {
          scopeList = null;
          execution = (ExecutionImpl) execution.getParent();
        } else {
          next = scopeList.get(index);
          return true;
        }
      }
    }
    return false;
  }

  private List<Object> findNextScopeList() {
    while ( (scopeList==null)
            && (execution!=null)
          ) {
      scopeList = getScopeListFromExecution();
      if (scopeList==null) {
        execution = (ExecutionImpl) execution.getParent();
      } else {
        return scopeList;
      }
    }
    return null;
  }

  private int findNextExecutionScopeIndex() {
    if (index==-1) {
      index = 0;
    }
    while (index<scopeList.size()) {
      Object executionScope = scopeList.get(index);
      if (isWanted(executionScope)) {
        return index;
      }
      index++;
    }
    return -1;
  }

  private Object consumeNext() {
    lastConsumedScopeList = scopeList;
    lastConsumedIndex = index;
    isConsumed = true;
    index++;
    return next;
  }
}
