/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jbpm.pvm.impl;

import java.util.LinkedList;
import java.util.List;

import org.jbpm.env.session.Message;
import org.jbpm.pvm.Node;

/**
 * @author Tom Baeyens
 */
public class ProceedToDestinationOp implements AtomicOperation {
  
  public boolean isAsync(ExecutionImpl execution) {
    return false;
  }

  public void perform(ExecutionImpl execution) {
    NodeImpl destination = execution.transition.getDestination();
    execution.node = destination;
    
    execution.node = destination;

    List<NodeImpl> enteredNodes = getNodesEntered(execution.transitionOrigin, destination);
    for (Node enteredNode : enteredNodes) {
      execution.fire(Node.EVENT_NODE_ENTER, enteredNode);
    }
    
    execution.moveTo(destination);

    execution.performAtomicOperation(ExecutionImpl.EXECUTE_NODE);
  }
  
  List<NodeImpl> getNodesEntered(NodeImpl transitionOrigin, NodeImpl destination) {
    LinkedList<NodeImpl> nodesEntered = new LinkedList<NodeImpl>();
    
    if (transitionOrigin.equals(destination)) {
      nodesEntered.addFirst(destination);
    } else {
      List<ObservableElementImpl> sourceChain = transitionOrigin.getParentChain();
      
      if (!sourceChain.contains(destination)) {
        NodeImpl destinationNode = destination;
        while ( (destinationNode!=null)
                && (!sourceChain.contains(destinationNode))
              ) {
          nodesEntered.addFirst(destinationNode);
          destinationNode = destinationNode.getParentNode(); 
        }
      }
    }

    return nodesEntered;
  }
  
  public String toString() {
    return "proceed-to-destination";
  }

  public Message<?> createAsyncMessage(ExecutionImpl execution) {
    return new ProceedToDestinationMessage(execution);
  }
}
