/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jbpm.pvm.type;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import org.jbpm.log.Log;

import org.jbpm.PvmException;
import org.jbpm.pvm.VariableScope;
import org.jbpm.pvm.impl.VariableTypeResolver;

/**
 * @author Tom Baeyens
 */
public class DefaultVariableTypeResolver implements VariableTypeResolver, Serializable {

  private static final long serialVersionUID = 1L;

  private static final Log log = Log.getLog(DefaultVariableTypeResolver.class.getName());
  
  List<TypeMapping> typeMappings;
  
  public Variable createVariable(String key, Object value, VariableScope variableScope) {
    Variable variable = null;
    
    if (typeMappings!=null) {
      Iterator<TypeMapping> iter = typeMappings.iterator();
      while ( (iter.hasNext())
        && (variable==null) ) {
        TypeMapping mapping = (TypeMapping) iter.next();
        
        if (mapping.matches(key, value)) {
          Class<?> variableClass = null;
          try {
            variableClass = mapping.getVariableClass();
            log.trace("creating new "+variableClass.getName()+" for variable "+key);
            variable = (Variable) variableClass.newInstance();
          } catch (Exception e) {
            throw new PvmException("couldn't instantiate variable instance class '"+variableClass.getName()+"'");
          }
          Converter converter = mapping.getConverter();
          variable.setConverter(converter);
        }
      }
    }

    return variable;
  }
  
  

  public void addTypeMapping(TypeMapping typeMapping) {
    if (typeMappings==null) {
      typeMappings = new ArrayList<TypeMapping>();
    }
    typeMappings.add(typeMapping);
  }
}
