/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jbpm.wire.binding;

import org.jbpm.wire.descriptor.AbstractDescriptor;
import org.jbpm.wire.descriptor.FalseDescriptor;
import org.jbpm.wire.descriptor.TrueDescriptor;
import org.jbpm.wire.xml.WireParser;
import org.jbpm.xml.Binding;

/**
 * <p>This {@link Binding} parses to a {@link TrueDescriptor} or {@link FalseDescriptor}.</p>
 *
 * <h4>Standard declaration</h4>
 * <p>A boolean descriptor is defined by a <b><code>{@literal <boolean>}</code></b> xml element.</p>
 *
 * <p>This element can have an attribute "name", which specifies the name of the created object in the WireContext.</p>
 * <p>This element must have an attribute "value", which specifies the value of the object.</p>
 *
 * <h4>Other possible declaration</h4>
 * <p>A 'true' booleanDescriptor can be defined by the <b><code>{@literal <true>}</code></b> xml element (see {@link TrueBinding}).</p>
 * <p>A 'false' booleanDescriptor can be defined by the <b><code>{@literal <false>}</code></b> xml element (see {@link FalseBinding}).</p>
 * <p>The two elements can have an attribute "name", which specifies the name of the created object in the WireContext.</p>
 *
 * <h3>Example</h3>
 *
 * The following Xml declaration will create
 * <ul>
 * <li>a Boolean 'b', with the value "true".</li>
 * <li>a Boolean 'b1', with the value "true".</li>
 * <li>a Boolean 'b2', with the value "false".</li>
 * </ul>
 * <pre> &lt;objects&gt;
 *   &lt;boolean name='b' value='true' /&gt;
 *   &lt;true name='b1' /&gt;
 *   &lt;false name='b2' /&gt;
 * &lt;/objects&gt;</pre>
 *
 * @see WireParser
 *
 * @author Tom Baeyens
 * @author Guillaume Porcher (Documentation)
 */
public class BooleanBinding extends BasicTypeBinding {

  protected AbstractDescriptor createDescriptor(String value) {
    if ("true".equalsIgnoreCase(value) ) {
      return new TrueDescriptor();
    } else if ("false".equalsIgnoreCase(value) ) {
      return new FalseDescriptor();
    }
    throw new IllegalArgumentException("value must be 'true' or 'false'");
  }
}