/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jbpm.wire.binding;

import java.io.InputStream;
import java.net.URL;
import java.util.ArrayList;
import java.util.Enumeration;
import java.util.List;
import org.jbpm.log.Log;

import org.jbpm.stream.InputStreamSource;
import org.jbpm.stream.UrlStreamSource;
import org.jbpm.util.ReflectUtil;
import org.jbpm.wire.Descriptor;
import org.jbpm.wire.descriptor.DeployerManagerDescriptor;
import org.jbpm.wire.xml.WireParser;
import org.jbpm.xml.Binding;
import org.jbpm.xml.Parse;
import org.jbpm.xml.Parser;
import org.jbpm.xml.XmlUtil;
import org.w3c.dom.Element;


/**
 * @author Tom Baeyens
 */
public class DeployerManagerBinding implements Binding {
  
  private static final Log log = Log.getLog(DeployerManagerBinding.class.getName());
  
  public Object parse(Element element, Parse parse, Parser parser) {
    DeployerManagerDescriptor descriptor = new DeployerManagerDescriptor();
    
    if (element.hasAttribute("resources")) {
      String resources = element.getAttribute("resources");
      try {
        Enumeration<URL> enumeration = ReflectUtil.getResources(parse.getClassLoader(), resources);
        if (enumeration!=null) {
          while (enumeration.hasMoreElements()) {
            URL url = enumeration.nextElement();
            log.trace("importing language deployers from "+url);
            parser.importStream(new UrlStreamSource(url), element, parse);
          }
        }
      } catch (Exception e) {
        parse.addProblem("couldn't parse language deployer resources '"+resources+"'", e);
      }
    }
 
    List<Element> languageElements = XmlUtil.elements(element, "language");
    if (languageElements!=null) {
      for (Element languageElement: languageElements) {
        String language = null;
        if (languageElement.hasAttribute("name")) {
          language = languageElement.getAttribute("name");
        } else {
          parse.addProblem("name is a required attribute in element language: "+XmlUtil.toString(languageElement));
        }
        
        String extension = null;
        if (element.hasAttribute("extension")) {
          language = element.getAttribute("extension");
        } 
        
        List<Descriptor> deployerDescriptors = new ArrayList<Descriptor>();

        List<Element> deployerElements = XmlUtil.elements(languageElement);
        if (deployerElements!=null) {
          for (Element deployerElement: deployerElements) {
            Descriptor deployerDescriptor = (Descriptor) parser
                .parseElement(deployerElement, 
                              parse, 
                              WireParser.CATEGORY_DESCRIPTOR);
            deployerDescriptors.add(deployerDescriptor);
          }
        }
        
        if (deployerDescriptors.isEmpty()) {
          parse.addProblem("no deployers defined for "+language);
        }

        descriptor.addLanguage(language, extension, deployerDescriptors);
      }
    }
    
    return descriptor;
  }

}
