/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jbpm.wire.binding;

import org.jbpm.wire.operation.EnlistOperation;
import org.jbpm.wire.xml.WireParser;
import org.jbpm.xml.Binding;
import org.jbpm.xml.Parse;
import org.jbpm.xml.Parser;
import org.w3c.dom.Element;

/**
 *
 * <p>This {@link Binding} specifies an {@link EnlistOperation}.
 * The object on which this operation is applied will be added
 * to the list of resource linked to the specified transaction
 * (committed on transaction commit, rolled back on transaction roll back...).</p>
 *
 * <p>A enlist operation is defined by a <b><code>{@literal <enlist>}</code></b> xml element.</p>
 *
 * <p>This element can have a attribute "transaction",
 * which specifies the name of the transaction to which the object should be linked.</p>
 * <p>If no "transaction" is found, a default name will be used.</p>
 *
 * @author Tom Baeyens
 * @author Guillaume Porcher (documentation)
 *
 * @see ObjectBinding
 * @see WireParser
 */
public class EnlistBinding implements Binding {

  public Object parse(Element element, Parse parse, Parser parser) {
    EnlistOperation enlistOperation = new EnlistOperation();
    if (element.hasAttribute("transaction")) {
      enlistOperation.setTransactionName(element.getAttribute("transaction"));
    }
    return enlistOperation;
  }
}