/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jbpm.wire.binding;

import org.jbpm.wire.descriptor.AbstractDescriptor;
import org.jbpm.wire.descriptor.IntegerDescriptor;
import org.jbpm.wire.xml.WireParser;
import org.jbpm.xml.Binding;

/**
 * <p>This {@link Binding} specifies an {@link IntegerDescriptor}.</p>
 *
 * <p>An integer descriptor is defined by a <b><code>{@literal <int>}</code></b> xml element.</p>
 *
 * <p>This element can have an attribute "name", which specifies the name of the created object in the WireContext.</p>
 * <p>This element must have an attribute "value", which specifies the value of the object.</p>
 *
 * <h3>Example</h3>
 *
 * The following Xml declaration will create an Integer 'i', with the value '42'.
 * <pre> &lt;objects&gt;
 *   &lt;int name='i' value='42' /&gt;
 * &lt;/objects&gt;</pre>
 *
 *
 * @author Tom Baeyens
 * @author Guillaume Porcher (documentation)
 *
 * @see WireParser
 */
public class IntBinding extends BasicTypeBinding {

  protected AbstractDescriptor createDescriptor(String value) {
    IntegerDescriptor integerDescriptor =  new IntegerDescriptor();
    Integer integerValue;
    try {
      integerValue = new Integer(value);
    } catch (NumberFormatException e) {
      throw new NumberFormatException("'"+value+"' cannot be parsed to an int");
    }
    integerDescriptor.setValue(integerValue);
    return integerDescriptor;
  }
}