/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jbpm.wire.binding;

import java.util.ArrayList;
import java.util.List;

import org.jbpm.wire.descriptor.CollectionDescriptor;
import org.jbpm.wire.descriptor.ListDescriptor;
import org.jbpm.wire.xml.WireParser;
import org.jbpm.xml.Binding;

/**
 *
 * <p>This {@link Binding} specifies a {@link ListDescriptor}.</p>
 *
 * <p>A List descriptor is defined by a <b><code>{@literal <list>}</code></b> xml element.</p>
 *
 * <p>This element can have an attribute "name", which specifies the name of the created object in the WireContext.</p>
 * <p>This element can have an attribute "class", which specifies the implementation of List to use.
 * If this attribute is not present, the {@link ArrayList} implementation is used.</p>
 *
 * <h4>List entries</h4>
 * <p>Entries to add to the list can be specified with child elements that specify the object to add.</p>
 *
 * <h3>Example</h3>
 *
 * The following Xml declaration will create a ArrayList, and store it under the name 'l'.
 * The list will contain two elements.
 *
 * <pre> &lt;objects&gt;
 *   &lt;list name='l' &gt;
 *     &lt;string value='foo'/&gt;
 *     &lt;object name='a' class='java.lang.Object' /&gt;
 *   &lt;/list&gt;
 * &lt;/objects&gt;</pre>
 *
 *
 * @author Tom Baeyens
 * @author Guillaume Porcher (documentation)
 *
 * @see WireParser
 */
public class ListBinding extends AbstractCollectionBinding {

  protected CollectionDescriptor createDescriptor() {
    return new ListDescriptor();
  }

  protected Class<?> getCollectionInterface() {
    return List.class;
  }
}