/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jbpm.wire.binding;

import java.sql.Connection;
import java.util.ArrayList;
import java.util.List;

import org.jbpm.wire.descriptor.ArgDescriptor;
import org.jbpm.wire.descriptor.ObjectDescriptor;
import org.jbpm.wire.descriptor.ReferenceDescriptor;
import org.jbpm.wire.operation.SubscribeOperation;
import org.jbpm.xml.Binding;
import org.jbpm.xml.Parse;
import org.jbpm.xml.Parser;
import org.jbpm.xml.XmlUtil;
import org.w3c.dom.Element;

/**
 * @author Tom Baeyens
 */
public class PersistenceSessionBinding implements Binding {

  public Object parse(Element element, Parse parse, Parser parser) {
    String factoryName = XmlUtil.attribute(element, "factory");
    ReferenceDescriptor factoryDescriptor = new ReferenceDescriptor();
    factoryDescriptor.setValue(factoryName);

    ObjectDescriptor persistenceSessionDescriptor = new ObjectDescriptor();
    persistenceSessionDescriptor.setFactoryDescriptor(factoryDescriptor);
    persistenceSessionDescriptor.setMethodName("openPersistenceSession");

    persistenceSessionDescriptor.setAutoWireEnabled(true);

    String connectionName = XmlUtil.attribute(element, "connection");
    if (connectionName!=null) {
      List<ArgDescriptor> argDescriptors = new ArrayList<ArgDescriptor>();
      persistenceSessionDescriptor.setArgDescriptors(argDescriptors);

      ArgDescriptor argDescriptor = new ArgDescriptor();
      argDescriptor.setTypeName(Connection.class.getName());
      ReferenceDescriptor connectionDescriptor = new ReferenceDescriptor();
      connectionDescriptor.setValue(connectionName);
      argDescriptor.setDescriptor(connectionDescriptor);
    }

    SubscribeOperation subscribeOperation = new SubscribeOperation();
    subscribeOperation.setWireEvents(false);
    persistenceSessionDescriptor.addOperation(subscribeOperation);
    
    return persistenceSessionDescriptor;
  }
}
