/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jbpm.wire.binding;

import org.jbpm.wire.descriptor.ReferenceDescriptor;
import org.jbpm.wire.xml.WireParser;
import org.jbpm.xml.Binding;
import org.jbpm.xml.Parse;
import org.jbpm.xml.Parser;
import org.jbpm.xml.XmlUtil;
import org.w3c.dom.Element;

/**
 * <p>This {@link Binding} specifies a {@link ReferenceDescriptor}.</p>
 *
 * <p>The object referenced should be declared somewhere else in the wireContext.</p>
 *
 * <p>A reference descriptor is defined by a <b><code>{@literal <ref>}</code></b> xml element.</p>
 *
 * <p>This element can have an attribute "name", which specifies the name of the created object in the WireContext.</p>
 * <p>This element must have an attribute "object", which specifies the name of the referenced object.</p>
 *
 * <h3>Example</h3>
 *
 * The following Xml declaration will get the object named 'o' in the wireContext, and store it under the name 'r'.
 * <pre> &lt;objects&gt;
 *   &lt;ref name='r' object='o' /&gt;
 * &lt;/objects&gt;</pre>
 *
 *
 * @author Tom Baeyens
 * @author Guillaume Porcher (documentation)
 *
 * @see WireParser
 */
public class RefBinding implements Binding {

  public Object parse(Element element, Parse parse, Parser parser) {
    ReferenceDescriptor descriptor = new ReferenceDescriptor();
    if (element.hasAttribute("object")) {
      descriptor.setValue(element.getAttribute("object"));
    } else {
      parse.addProblem("ref must have object attribute: "+XmlUtil.toString(element));
    }
    return descriptor;
  }
}